/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.tests;

import java.io.File;
import java.util.List;
import static org.thermostat.qa2.framework.Assert.assertEquals;
import org.thermostat.qa2.framework.NativeProcess;
import org.thermostat.qa2.framework.ThermostatQAConfig;
import org.thermostat.qa2.framework.annotations.SetupThermostat;
import org.thermostat.qa2.framework.annotations.Test;
import org.thermostat.qa2.framework.utils.FileUtilities;

/**
 * Test class ported from old framework
 * @author Zdeněk Žamberský
 */
@SetupThermostat
public class OutputMessagesTest {

    public static void checkHelpMessage(String[] commands) throws Exception {
        String fileName = "thermostat";
        String[] allCommands = new String[commands.length + 1];
        allCommands[0] = ThermostatQAConfig.getThermostatExecutablePath();

        for (int i = 0; i < commands.length; ++i) {
            fileName += "_" + commands[i];
            allCommands[i + 1] = commands[i];
        }

        NativeProcess process = new NativeProcess(allCommands);
        process.setEnvironmentVariable("USER_THERMOSTAT_HOME", ThermostatQAConfig.getThermostatUserHome());
        process.setStdOutMode(NativeProcess.MODE_LOG_AND_BUFFER);
        process.setLabel("thermostat");
        process.start();
        process.waitFor();
        List<String> output = process.getStdoutLines();

        fileName = ThermostatQAConfig.getThermostatOutputTextsDir() + File.separator + fileName + ".txt";
        List<String> expected = FileUtilities.getLineListFromFile(fileName);

        assertEquals(output, expected);
    }

    @Test
    public void standardMessage() throws Exception {
        String[] commands = {};
        checkHelpMessage(commands);
    }

    @Test
    public void helpMessage() throws Exception {
        String[] commands = {"help"};
        checkHelpMessage(commands);
    }

    @Test
    public void agentHelpMessage() throws Exception {
        String[] commands = {"help", "agent"};
        checkHelpMessage(commands);
    }

    @Test
    public void ConnectHelpMessage() throws Exception {
        String[] commands = {"help", "connect"};
        checkHelpMessage(commands);
    }

    @Test
    public void DisconnectHelpMessage() throws Exception {
        String[] commands = {"help", "disconnect"};
        checkHelpMessage(commands);
    }

    @Test
    public void dumpHeapHelpMessage() throws Exception {
        String[] commands = {"help", "dump-heap"};
        checkHelpMessage(commands);
    }

    @Test
    public void findObjectsHelpMessage() throws Exception {
        String[] commands = {"help", "find-objects"};
        checkHelpMessage(commands);
    }

    @Test
    public void findRootHelpMessage() throws Exception {
        String[] commands = {"help", "find-root"};
        checkHelpMessage(commands);
    }

    @Test
    public void guiHelpMessage() throws Exception {
        String[] commands = {"help", "gui"};
        checkHelpMessage(commands);
    }

    @Test
    public void listHeapDumpsHelpMessage() throws Exception {
        String[] commands = {"help", "list-heap-dumps"};
        checkHelpMessage(commands);
    }

    @Test
    public void listVmsHelpMessage() throws Exception {
        String[] commands = {"help", "list-vms"};
        checkHelpMessage(commands);
    }

    @Test
    public void objectInfoHelpMessage() throws Exception {
        String[] commands = {"help", "object-info"};
        checkHelpMessage(commands);
    }

    @Test
    public void pingHelpMessage() throws Exception {
        String[] commands = {"help", "ping"};
        checkHelpMessage(commands);
    }

    @Test
    public void saveHeapDumpToFileHelpMessage() throws Exception {
        String[] commands = {"help", "save-heap-dump-to-file"};
        checkHelpMessage(commands);
    }

    @Test
    public void showHeapHistogramHelpMessage() throws Exception {
        String[] commands = {"help", "show-heap-histogram"};
        checkHelpMessage(commands);
    }

    @Test
    public void serviceHelpMessage() throws Exception {
        String[] commands = {"help", "service"};
        checkHelpMessage(commands);
    }

    @Test
    public void shellHelpMessage() throws Exception {
        String[] commands = {"help", "shell"};
        checkHelpMessage(commands);
    }

    @Test
    public void storageHelpMessage() throws Exception {
        String[] commands = {"help", "storage"};
        checkHelpMessage(commands);
    }

    @Test
    public void vmInfoHelpMessage() throws Exception {
        String[] commands = {"help", "vm-info"};
        checkHelpMessage(commands);
    }

    @Test
    public void vmStatHelpMessage() throws Exception {
        String[] commands = {"help", "vm-stat"};
        checkHelpMessage(commands);
    }
}
